Index: chrome/browser/cocoa/toolbar_controller_unittest.mm |
diff --git a/chrome/browser/cocoa/toolbar_controller_unittest.mm b/chrome/browser/cocoa/toolbar_controller_unittest.mm |
index c5f155dfc64ff724795a93d4b6a16595e25ddaca..23fc583f81fc7c4f1124f1d87d15475f68083cd4 100644 |
--- a/chrome/browser/cocoa/toolbar_controller_unittest.mm |
+++ b/chrome/browser/cocoa/toolbar_controller_unittest.mm |
@@ -9,6 +9,7 @@ |
#include "chrome/browser/cocoa/browser_test_helper.h" |
#import "chrome/browser/cocoa/cocoa_test_helper.h" |
#import "chrome/browser/cocoa/gradient_button_cell.h" |
+#import "chrome/browser/cocoa/reload_button.h" |
#import "chrome/browser/cocoa/toolbar_controller.h" |
#import "chrome/browser/cocoa/view_resizer_pong.h" |
#include "chrome/browser/pref_service.h" |
@@ -150,14 +151,14 @@ TEST_F(ToolbarControllerTest, FocusLocation) { |
} |
TEST_F(ToolbarControllerTest, LoadingState) { |
// In its initial state, the reload button has a tag of |
// IDC_RELOAD. When loading, it should be IDC_STOP. |
- NSButton* reload = [[bar_ toolbarViews] objectAtIndex:kReloadIndex]; |
- EXPECT_EQ([reload tag], IDC_RELOAD); |
+ ReloadButton* reload = [[bar_ toolbarViews] objectAtIndex:kReloadIndex]; |
+ EXPECT_EQ([reload command], IDC_RELOAD); |
[bar_ setIsLoading:YES force:YES]; |
- EXPECT_EQ([reload tag], IDC_STOP); |
+ EXPECT_EQ([reload command], IDC_STOP); |
[bar_ setIsLoading:NO force:YES]; |
- EXPECT_EQ([reload tag], IDC_RELOAD); |
+ EXPECT_EQ([reload command], IDC_RELOAD); |
} |
// Check that toggling the state of the home button changes the visible |
@@ -150,14 +151,14 @@ TEST_F(ToolbarControllerTest, FocusLocation) { |
} |
TEST_F(ToolbarControllerTest, LoadingState) { |
- // In its initial state, the reload button has a tag of |
+ // In its initial state, the reload button has a command of |
// IDC_RELOAD. When loading, it should be IDC_STOP. |